@@ -15,7 +15,7 @@ class IFeature:
         return self._instance.Description
 
     @property
-    def id_(self):
+    def identity(self):
         return self._instance.GetID
 
     @property
@@ -50,6 +50,8 @@ class IFeature:
         return self._instance.GetNextFeature
 
     def get_box(self):
-        arg = win32com.client.VARIANT(pythoncom.VT_BYREF | pythoncom.VT_VARIANT, None)
+        arg = win32com.client.VARIANT(
+            pythoncom.VT_BYREF | pythoncom.VT_VARIANT, None
+        )
         self._instance.GetBox(arg)
         return arg.value
